@@ -22,9 +22,11 @@ class FronteggProxy(FronteggAuthenticator, IdentityClientMixin):
         if not path:
             raise Exception('path is required')
 
-        path_without_frontegg = path.replace(self.middleware_prefix, '').replace('/'+self.middleware_prefix, '')
+        path_without_frontegg = path.replace(
+            '/'+self.middleware_prefix, '', 1).replace(self.middleware_prefix, '', 1)
 
-        public_route = self.is_public_route(path_without_frontegg, params, method)
+        public_route = self.is_public_route(
+            path_without_frontegg, params, method)
 
         if self.authentication_middleware is not None and not public_route:
             try:
@@ -35,7 +37,7 @@ class FronteggProxy(FronteggAuthenticator, IdentityClientMixin):
                 return HttpException('Something went wrong', 500)
 
         url = urljoin(frontegg_urls.base_url, path_without_frontegg)
-        headers = self.clean_headers(headers, host)
+        headers = self.clean_request_headers(headers, host)
         headers = self.set_context(headers, request)
 
         if self.should_refresh_vendor_token:
@@ -50,9 +52,11 @@ class FronteggProxy(FronteggAuthenticator, IdentityClientMixin):
             params=params
         )
 
+        response.headers = self.clean_response_headers(response.headers)
+
         return response
 
-    def clean_headers(self, headers: dict, host: str) -> dict:
+    def clean_request_headers(self, headers: dict, host: str) -> dict:
         new_headers = dict()
         ignored_headers = ['host', 'authorization']
         for key, value in headers.items():
@@ -62,12 +66,24 @@ class FronteggProxy(FronteggAuthenticator, IdentityClientMixin):
         new_headers[frontegg_headers['vendor_host']] = host
         return new_headers
 
+    def clean_response_headers(self, headers: dict) -> dict:
+        new_headers = dict()
+
+        ignored_headers = ['access-control-allow-credentials',
+                           'access-control-allow-origin']
+
+        for key, value in headers.items():
+            if key.lower() not in ignored_headers:
+                new_headers[key] = value
+
+        return new_headers
+
     def set_context(self, headers: dict, request) -> dict:
         context = self.context_callback(request)
-        if context.get('tenant_id'):
-            headers[frontegg_headers['tenant_id']] = context['tenant_id']
-        if context.get('user_id'):
-            headers[frontegg_headers['user_id']] = context['user_id']
+        if context.tenant_id != None:
+            headers[frontegg_headers['tenant_id']] = context.tenant_id
+        if context.user_id != None:
+            headers[frontegg_headers['user_id']] = context.user_id
 
         return headers
 
